# func_adl.xAOD
 Client interface to send a hierarchical SQL-like query to an xAOD backend

[![Travis Build Badge](https://travis-ci.org/iris-hep/func_adl.xAOD.svg?branch=master)](https://travis-ci.org/iris-hep/func_adl.xAOD)
[![Code Coverage](https://codecov.io/gh/iris-hep/func_adl.xAOD/graph/badge.svg)](https://codecov.io/gh/iris-hep/func_adl.xAOD)

## Introduction

This allows you to query hierarchical data stored in a root file that has been written using the ATLAS xAOD format.
This code allows you to query that.
